package easyIo;

import java.awt.*;
import java.awt.event.*;

/*****************************************************************************
 * The <CODE>OutputTextWindow</CODE> class creates a text window to capture 
 * text in.
 * <p>
 * This class was written as an alternative to writing to the shell prompt,
 * as most windows offer better textual control than a shell. This affords the
 * user the ability to use a windowed environment without bothering with small
 * details. It has a set of very simple methods to write to the window.
 *
 * <dt><b>Source code is located at:</b><dd>
 *   <A HREF="http://gatehansen.tripod.com/dloads/JavaCode/">
 *   http://gatehansen.tripod.com/dloads/JavaCode/
 *   </A>
 * @author
 *   James P. Hansen (hans1732@tc.umn.edu,gateman9@mn.rr.com)
 * @version
 *   0.01d
 *****************************************************************************/
public class OutputTextWindow {
    
    private Frame outputWindow;  //The window itself, that will hold the text
    private TextArea outputText; //The text field, put in the window
    /**
    * Initialize this <CODE>OutputTextWindow</CODE> with a window title,
    * number of rows of text, and number of columns.
    * @param <CODE>title</CODE>
    *   represents the desired title of the window
    * @param <CODE>rows</CODE>
    *   specifies how high in terms of lines of text the window will be
    * @param <CODE>columns</CODE>
    *   specifies how wide in terms of characters the window will be, should be
    *   around <i>80</i> for readability purposes
    * <dt><b>Postcondition:</b><dd>
    *   A window is created with the specified number of <CODE>rows</CODE> and 
    *   <CODE>columns</CODE> with <CODE>title</CODE> and brought to the main
    *   focus of the OS
    * <dt><b>Example:</b><dd>
    *   <CODE>OutputTextWindow myOut = new OutputTextWindow("FOO",9,67);</CODE>
    *   <BR>Creates a window titled foo that is nine lines long and 67 
    *   characters
    *   wide.
    **/
    public OutputTextWindow(String title, int rows, int columns) {
	outputText = new TextArea(rows,columns);
	outputWindow = new Frame(title);
	outputWindow.add(outputText,BorderLayout.CENTER);
	outputWindow.pack();
	outputWindow.setResizable(false);
	outputWindow.show();
	outputWindow.toFront();
    }
    /**
    * Initialize this <CODE>OutputTextWindow</CODE> with a no window title,
    * number of rows of text, and number of columns.
    * @param <CODE>rows</CODE>
    *   specifies how high in terms of lines of text the created window will be
    * @param <CODE>columns</CODE>
    *   specifies how wide in terms of characters the created window will be
    * <dt><b>Postcondtition:</b><dd>
    *   A window is created with the specified number of <CODE>rows</CODE> and
    *  <CODE>columns</CODE> and brought to the main focus of the OS
    * <dt><b>Example:</b><dd>
    *   <CODE>OutotuTextWindow myOut = new OutputTextWindow(25,80);</CODE>
    *   <BR>Creates an untitled window 25 lines long and 80 characters wide.
    **/
    public OutputTextWindow(int rows, int columns){
	outputText = new TextArea(rows,columns);
	outputWindow = new Frame("Untitled");
	outputWindow.add(outputText,BorderLayout.CENTER);
	outputWindow.pack();
	outputWindow.setResizable(false);
	outputWindow.show();
	outputWindow.toFront();
    }
    /**
    * Initialize this <CODE>OutputTextWindow</CODE> to have no title, and to 
    * the default size.
    * @param <CODE>none</CODE>
    * <dt><b>Postcondition:</b><dd>
    *   A window is created with 25 lines of text of 80 characters.
    * <dt><b>Example:</b><dd>
    *   <CODE>OutputTextWindow myOut = new OutPutTextWindow();</CODE>
    *   <BR>Creates a window with no title and the default size.
    */
    public OutputTextWindow() {
	outputText = new TextArea(25,80);
	outputWindow = new Frame("Untitled");
	outputWindow.add(outputText,BorderLayout.CENTER);
	outputWindow.pack();
	outputWindow.setResizable(false);
	outputWindow.show();
	outputWindow.toFront();
    }
    /**
    * Ends the window and performs other actions based on <CODE>selection</CODE>
    * @param <CODE>selection</CODE>
    *   Determines what actions to perform after closing the window. A value
    *   of <i>0</i> will close the window. A value of <i>1</i> will close the
    *   window and terminate the program. Any other value will just close the
    *   window.
    * <dt><b>Postcondition:</b><dd>
    *   Terminates this window, and does other actions base on the value given
    *   to <CODE>selection</CODE>.
    */
    public void closeWindow(int selection) {
	outputWindow.dispose();
	switch(selection) {
	case 0: break;
	case 1: System.exit(0);
	    break;
	default: break;
	}
    }
    /** 
    * Ends the window and exits the program.
    * @param <CODE>none</CODE>
    * <dt><b>Postcondition:</b><dd>
    *   Terminates the program after destroying the window. Do not call if more
    *   code follows this statement.
    */
    public void closeWindow() {
	outputWindow.dispose();
	System.exit(0);
    }
    /** 
    * Puts text into the window on a single line, unless <CODE>line</CODE> has
    * control characters in it.
    * @param <CODE>line</CODE>
    *   String of characters to put in the window.  May contain any valid set
    *   of characters.
    * <dt><b>Postcondition:</b><dd>
    *   <CODE>line</CODE> is entered at the end of the current line of text.
    * <dt><b>Example:</b><dd>
    *   <CODE> OutputTextWindow myOut = new OutputTextWindow();<BR>
    *   myOut.print("Go Twins!");</CODE><BR>
    *   Prints the string <i>"Go Twins!"</i> at the end of the current line.
    * @see java.lang.System
    * @see java.io.PrintStream.print(String)
    */
    public void print(String line) {
	outputText.append(line);
    }
    /** 
    * Puts <CODE>line</CODE> in the window and starts a new line.
    * @param <CODE>line</CODE>
    *   a string to be put in the window.  Can contain any valid characters,
    *   but control charcters are not recommended.
    * <dt><b>Postcondition:</b><dd>
    *   <CODE>line</CODE> is printed as well as a new line.
    * @see java.lang.System
    * @see java.io.PrintStream.println(String)
    */
    public void println(String line) {
	outputText.append(line + "\n");
    }
    /** 
    * Here to maintain similarity between this and System.out.println();
    * @see java.lang.System
    * @see java.io.Printstream.println()
    */
    public void println() {
	outputText.append("\n");
    }
    /** 
    * Perfroms the same as <CODE>print(String line)</CODE>, except for printing
    * to the standard out as well.
    * @param <CODE>line</CODE>
    * @see #print(String line)
    */
    public void printMirror(String line) {
	outputText.append(line);
	System.out.print(line);
    }
    /** 
    * Performs the same as <CODE>println(String line)</CODE>, except for 
    * printing to the standard out as well.
    * @param <CODE>line</CODE>
    * @see #println(String line)
    */
    public void printlnMirror(String line) {
	outputText.append(line);
	outputText.append("\n");
	System.out.println(line);
    }
    /** 
    * Performs the smae as <CODE>println()</CODE>, except for printing to the
    * standard out as well.
    * @see #println()
    */
    public void printlnMirror() {
	outputText.append("\n");
	System.out.println();
    }
}
